exceptiontools.TupletFuseError
==============================

.. inheritance-diagram:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletFuseError.TupletFuseError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
